@@ -269,12 +269,12 @@ class ApplicationAPI:
         if data_status:
             data["data_status"] = data_status
         
-        response = self.client.get('/api/application/list', data=data)
+        response = self.client.post('/api/application/list', data=data)
         return response
     
     def update(
         self,
-        application_data: Dict[str, Any],
+        application_data: List[Dict[str, Any]],
         execute_release: bool = False
     ) -> Dict[str, Any]:
         """
@@ -287,14 +287,15 @@ class ApplicationAPI:
         Returns:
             操作结果
         """
-        if not isinstance(application_data, dict):
-            raise SARMValidationError("应用数据必须是字典类型")
+        if not isinstance(application_data, list):
+            raise SARMValidationError("应用数据必须是列表类型")
         
         if 'application' not in application_data:
             raise SARMValidationError("缺少 application 字段")
         
         # 验证应用数据
-        self._validate_application_data(application_data['application'])
+        for app in application_data:
+            self._validate_application_data(app['application'])
         
         response = self.client.post(
             '/api/application/update',
@@ -303,11 +304,8 @@ class ApplicationAPI:
         )
         return response
     
-    def delete_business_system(self, app_id: str, business_system_id: str) -> Dict[str, Any]:
+    def delete_business_system(self, app_name: List[str]) -> Dict[str, Any]:
         """删除应用的业务系统关联"""
-        data = {
-            "app_id": app_id,
-            "business_system_id": business_system_id
-        }
+        data = app_name
         response = self.client.delete('/api/application/delete_business_system', data=data)
         return response 
\ No newline at end of file
