@@ -73,7 +73,7 @@ class VulnDataImportAPI:
             raise SARMValidationError(f"第{record_index}条数据的 vuln_list[{list_index}] 必须是字典类型")
         # 必填字段
         required_string_fields = [
-            'vuln_unique_id', 'simhash', 'severity', 'status', 'security_capability_unique_id'
+            'vuln_unique_id', 'severity', 'status', 'security_capability_unique_id'
         ]
         for f in required_string_fields:
             if f not in vuln:
