@@ -38,7 +38,12 @@ class OrganizationAPI:
         # 验证必填字段
         if 'organize_name' not in organization:
             raise SARMValidationError(f"第{record_index}条记录缺少必填字段 organize_name")
-        
+        if 'organize_unique_id' not in organization:
+            raise SARMValidationError(f"第{record_index}条记录缺少必填字段 organize_name")
+        if 'organize_punique_id' not in organization:
+            raise SARMValidationError(f"第{record_index}条记录缺少必填字段 organize_name")
+
+
         # 验证数据类型
         if 'organize_unique_id' in organization and not isinstance(organization['organize_unique_id'], str):
             raise SARMValidationError(f"第{record_index}条记录的 organize_unique_id 必须是字符串类型")
@@ -63,19 +68,17 @@ class OrganizationAPI:
             raise SARMValidationError(f"第{record_index}条记录的 organize_name 不能为空字符串")
         if organization['organize_unique_id'].strip() == '':
             raise SARMValidationError(f"第{record_index}条记录的 organize_unique_id 不能为空字符串")
-        if organization['organize_punique_id'].strip() == '':
-            raise SARMValidationError(f"第{record_index}条记录的 organize_unique_id 不能为空字符串")
 
     def create_batch(
         self,
-        organizations: List[OrganizeInsert],
+        organizations: List[Dict[str, Any]],
         execute_release: bool = False
-    ) -> BatchOperationResult:
+    ):
         """
         批量创建组织
         
         Args:
-            organizations: 组织数据列表
+            organizations: 组织数据列表，每个元素为字典格式
             execute_release: 是否直接发布，默认False进入预处理状态
             
         Returns:
@@ -94,13 +97,11 @@ class OrganizationAPI:
         # 验证数据
         org_data = []
         for i, org in enumerate(organizations):
-            if isinstance(org, OrganizeInsert):
-                org_dict = org.dict()
-                self._validate_organization_data(org_dict, i + 1)
-                org_data.append(org_dict)
-            else:
+            if isinstance(org, dict):
                 self._validate_organization_data(org, i + 1)
                 org_data.append(org)
+            else:
+                raise SARMValidationError(f"第{i+1}条组织数据必须是字典类型")
         
         # 发送请求
         response = self.client.post(
@@ -117,15 +118,8 @@ class OrganizationAPI:
             items = []
             for i, org in enumerate(organizations):
                 # 正确获取组织信息
-                if isinstance(org, dict):
-                    unique_id = org.get('organize_unique_id', f"org_{i}")
-                    name = org.get('organize_name', '')
-                elif hasattr(org, 'organize_unique_id'):
-                    unique_id = getattr(org, 'organize_unique_id', f"org_{i}")
-                    name = getattr(org, 'organize_name', '')
-                else:
-                    unique_id = f"org_{i}"
-                    name = ''
+                unique_id = org.get('organize_unique_id', f"org_{i}")
+                name = org.get('organize_name', '')
                 
                 items.append(BatchOperationItem(
                     unique_id=unique_id,
@@ -141,32 +135,32 @@ class OrganizationAPI:
         
         return BatchOperationResult(**response)
     
-    def create(self, organization: OrganizeInsert, execute_release: bool = False) -> BatchOperationResult:
+    def create(self, organization: Dict[str, Any], execute_release: bool = False):
         """
         创建单个组织
         
         Args:
-            organization: 组织数据
+            organization: 组织数据，字典格式
             execute_release: 是否直接发布
             
         Returns:
             批量操作结果
         """
-        if not isinstance(organization, (OrganizeInsert, dict)):
-            raise SARMValidationError("组织数据必须是 OrganizeInsert 对象或字典类型")
+        if not isinstance(organization, dict):
+            raise SARMValidationError("组织数据必须是字典类型")
         
         return self.create_batch([organization], execute_release=execute_release)
     
     def update_batch(
         self,
-        organizations: List[OrganizeInsert],
+        organizations: List[Dict[str, Any]],
         execute_release: bool = False
-    ) -> BatchOperationResult:
+    ):
         """
         批量更新组织
         
         Args:
-            organizations: 组织数据列表
+            organizations: 组织数据列表，每个元素为字典格式
             execute_release: 是否直接发布
             
         Returns:
@@ -178,13 +172,11 @@ class OrganizationAPI:
         # 验证数据
         org_data = []
         for i, org in enumerate(organizations):
-            if isinstance(org, OrganizeInsert):
-                org_dict = org.dict()
-                self._validate_organization_data(org_dict, i + 1)
-                org_data.append(org_dict)
-            else:
+            if isinstance(org, dict):
                 self._validate_organization_data(org, i + 1)
                 org_data.append(org)
+            else:
+                raise SARMValidationError(f"第{i+1}条组织数据必须是字典类型")
         
         # 发送请求
         response = self.client.post(
@@ -201,15 +193,8 @@ class OrganizationAPI:
             items = []
             for i, org in enumerate(organizations):
                 # 正确获取组织信息
-                if isinstance(org, dict):
-                    unique_id = org.get('organize_unique_id', f"org_{i}")
-                    name = org.get('organize_name', '')
-                elif hasattr(org, 'organize_unique_id'):
-                    unique_id = getattr(org, 'organize_unique_id', f"org_{i}")
-                    name = getattr(org, 'organize_name', '')
-                else:
-                    unique_id = f"org_{i}"
-                    name = ''
+                unique_id = org.get('organize_unique_id', f"org_{i}")
+                name = org.get('organize_name', '')
                 
                 items.append(BatchOperationItem(
                     unique_id=unique_id,
@@ -225,19 +210,19 @@ class OrganizationAPI:
         
         return BatchOperationResult(**response)
     
-    def update(self, organization: OrganizeInsert, execute_release: bool = False) -> BatchOperationResult:
+    def update(self, organization: Dict[str, Any], execute_release: bool = False):
         """
         更新单个组织
         
         Args:
-            organization: 组织数据
+            organization: 组织数据，字典格式
             execute_release: 是否直接发布
             
         Returns:
             批量操作结果
         """
-        if not isinstance(organization, (OrganizeInsert, dict)):
-            raise SARMValidationError("组织数据必须是 OrganizeInsert 对象或字典类型")
+        if not isinstance(organization, dict):
+            raise SARMValidationError("组织数据必须是字典类型")
         
         return self.update_batch([organization], execute_release=execute_release)
     
@@ -269,7 +254,7 @@ class OrganizationAPI:
         
         response = self.client.post(
             '/api/organize/openapi/delete',
-            data=unique_ids
+            data = unique_ids
         )
         
         return response
@@ -355,7 +340,7 @@ class OrganizationAPI:
         response = self.client.get('/api/organize/async_refresh_organize_tree_cache')
         return response
     
-    def get_tree(self) -> List[OrganizationTree]:
+    def get_tree(self) :
         """
         获取组织架构树
         
@@ -389,7 +374,7 @@ class OrganizationAPI:
         # 构建组织树
         return self._build_organization_tree(all_orgs)
     
-    def _build_organization_tree(self, organizations: List[Dict[str, Any]]) -> List[OrganizationTree]:
+    def _build_organization_tree(self, organizations: List[Dict[str, Any]]):
         """
         构建组织架构树
         
@@ -450,13 +435,13 @@ class OrganizationAPI:
     def create_users(
         self,
         organize_unique_id: str,
-        users: List[OrganizeUser]
+        users: List[Dict[str, Any]]
     ) -> Dict[str, Any]:
         """
         批量创建组织用户
         
         Args:
-            organize_union_id: 组织唯一ID
+            organize_unique_id: 组织唯一ID
             users: 用户数据列表
             
         Returns:
@@ -491,7 +476,7 @@ class OrganizationAPI:
         response = self.client.post('/api/organize_user/create', data=request_data)
         return response
     
-    def update_users(self, users: List[OrganizeUser]) -> Dict[str, Any]:
+    def update_users(self, users: List[Dict[str, Any]]) -> Dict[str, Any]:
         """
         批量更新组织用户
         
@@ -509,12 +494,9 @@ class OrganizationAPI:
         
         user_data = []
         for i, user in enumerate(users):
-            if isinstance(user, OrganizeUser):
-                user_data.append(user.dict())
-            else:
-                if not isinstance(user, dict):
-                    raise SARMValidationError(f"第{i+1}个用户数据必须是字典类型")
-                user_data.append(user)
+            if not isinstance(user, dict):
+                raise SARMValidationError(f"第{i+1}个用户数据必须是字典类型")
+            user_data.append(user)
         
         response = self.client.post('/api/organize_user/update', data=user_data)
         return response
@@ -648,4 +630,4 @@ class OrganizationAPI:
         }
         
         response = self.client.post('/api/organize_user/list', data=query_data)
-        return response
\ No newline at end of file
+        return response
