@@ -24,13 +24,13 @@ class SecurityCapabilityAPI:
 
     def create_batch(
         self,
-        capabilities: List[SecurityCapability]
+        capabilities: List[Dict[str, Any]]
     ) -> Dict[str, Any]:
         """
         批量创建安全能力
         
         Args:
-            capabilities: 安全能力数据列表
+            capabilities: List[Dict[str, Any]] - 安全能力数据列表
             
         Returns:
             操作结果
@@ -50,7 +50,7 @@ class SecurityCapabilityAPI:
         response = self.client.post('/api/security_capability/add_list', data=capability_data)
         return response
     
-    def create(self, capability: SecurityCapability) -> Dict[str, Any]:
+    def create(self, capability: Dict[str, Any]) -> Dict[str, Any]:
         """创建单个安全能力"""
         return self.create_batch([capability])
     
@@ -80,10 +80,7 @@ class SecurityCapabilityAPI:
         response = self.client.post('/api/security_capability/update_list', data=capabilities)
         return response
     
-    def update(self, capability_id: str, data: Dict[str, Any]) -> Dict[str, Any]:
-        """更新单个安全能力"""
-        capability_data = {"capability_id": capability_id, **data}
-        return self.update_batch([capability_data])
+
     
     def delete(self, capability_id: List[str]) -> Dict[str, Any]:
         """删除安全能力"""
